Class: Metanorma::BasicDocument::Change::ContentChangeAction

Inherits:
Lutaml::Model::Serializable
  • Object
show all
Defined in:
lib/metanorma/basic_document/change/content_change_action.rb

Overview

The actual content changes that applies to the specified portion of textual content. This is used both by the ContentModify and AttributeModify models as their content are treated as pure text.

Direct Known Subclasses

AttributeChangeAction