Class: Metanorma::BasicDocument::EmptyElements::IndexElement

Inherits:
BasicElement
  • Object
show all
Defined in:
lib/metanorma/basic_document/empty_elements/index_element.rb

Overview

Index term, defined as applying to the location in the text where the index element appears, as a milestone.