Class: Metanorma::BasicDocument::MultiParagraph::AdmonitionBlock

Inherits:
ParagraphsBlock show all
Defined in:
lib/metanorma/basic_document/multi_paragraph/admonition_block.rb

Overview

A sidebar block outside of the main flow of text, conveying particular warnings or supplementary text to the reader.