Class: Metanorma::BasicDocument::ReferenceElements::Callout

Inherits:
ReferenceToIdElement show all
Defined in:
lib/metanorma/basic_document/reference_elements/callout.rb

Overview

Inline reference to a paragraph or paragraphs, appearing as annotation of source code. The target of the callout is understood to be the location of the callout within the source code; the extent of the target is not expressed overtly.