Class: Metanorma::BasicDocument::ReferenceElements::IndexXrefElement
- Inherits:
-
ReferenceElement
- Object
- Lutaml::Model::Serializable
- EmptyElements::BasicElement
- ReferenceElement
- Metanorma::BasicDocument::ReferenceElements::IndexXrefElement
- Defined in:
- lib/metanorma/basic_document/reference_elements/index_xref_element.rb
Overview
A reference to an index term, cross-referenced within an index as an alternative index entry, either as a “see” or a “see also” cross-reference. The text in the inline element is the primary index term to be be cross-referenced.