Class: Metanorma::BasicDocument::Sections::BasicSection

Inherits:
Lutaml::Model::Serializable
  • Object
show all
Defined in:
lib/metanorma/basic_document/sections/basic_section.rb

Overview

Group of blocks within text, which is a leaf node in the hierarchical organisation of text (does not contain any sections of its own).

Direct Known Subclasses

HierarchicalSection, ReferencesSection