Class: Metanorma::Collection::Root

Inherits:
Lutaml::Model::Serializable
  • Object
show all
Defined in:
lib/metanorma/collection/root.rb

Overview

Root model for XML. Represents a collection of Metanorma documents bundled together, with shared metadata, directives, and a manifest of entries.

The collection root has no namespace (semantic) or xmlns="http://metanorma.org" (presentation). Embedded documents inside doc-containers use the standoc namespace (https://www.metanorma.org/ns/standoc).