Class: Metanorma::Document::Components::AncillaryBlocks::LiteralBlock

Inherits:
Lutaml::Model::Serializable
  • Object
show all
Defined in:
lib/metanorma/document/components/ancillary_blocks/literal_block.rb

Overview

Pre-formatted blocks are wrappers for text to be rendered with fixed-width typeface, and preserving spaces including line breaks. They are intended for a restricted number of functions, most typically ASCII Art (which is still in prominent use in some standards documents), and computer output. In most cases, Sourcecode blocks are more appropriate in markup, as it is more clearly motivated semantically.