Class: Metanorma::Document::Components::Change::ContentChangeAction
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Metanorma::Document::Components::Change::ContentChangeAction
- Defined in:
- lib/metanorma/document/components/change/content_change_action.rb
Overview
The actual content changes that applies to the specified portion of textual content. This is used both by the ContentModify and AttributeModify models as their content are treated as pure text.