Class: Metanorma::Document::Components::EmptyElements::IndexElement

Inherits:
BasicElement
  • Object
show all
Defined in:
lib/metanorma/document/components/empty_elements/index_element.rb

Overview

Index term, defined as applying to the location in the text where the index element appears, as a milestone.