Class: Metanorma::Document::Components::IdElements::IdElement

Inherits:
EmptyElements::BasicElement show all
Defined in:
lib/metanorma/document/components/id_elements/id_element.rb

Overview

BasicElement with an identifier, to be used in crossreferencing by Reference Elements. The IdElement itself acts as a reference point, such as in a SourcecodeBlock for callout references (the IdElement is the location), and for delimiting ReviewComment start/end places.

Direct Known Subclasses

Bookmark, Media