Class: Metanorma::Document::Components::MultiParagraph::AdmonitionBlock

Inherits:
ParagraphsBlock show all
Defined in:
lib/metanorma/document/components/multi_paragraph/admonition_block.rb

Overview

A sidebar block outside of the main flow of text, conveying particular warnings or supplementary text to the reader.

Instance Method Summary collapse

Methods inherited from Paragraphs::ParagraphBlock

#json_content

Instance Method Details

#json_typeObject



37
38
39
# File 'lib/metanorma/document/components/multi_paragraph/admonition_block.rb', line 37

def json_type
  "admonition"
end