Class: Metanorma::Document::Components::Paragraphs::ParagraphWithFootnote

Inherits:
ParagraphBlock show all
Defined in:
lib/metanorma/document/components/paragraphs/paragraph_with_footnote.rb

Overview

A paragraph which may also contain footnotes. While most paragraphs in a document can contain footnotes, the distinction is necessary, as footnotes are not appropriate for all instances of paragraph content in a document (e.g. sourcecode annotations).

Direct Known Subclasses

MultiParagraph::ParagraphsBlock

Method Summary

Methods inherited from ParagraphBlock

#json_content, #json_type