Class: Metanorma::Document::Components::ReferenceElements::Callout
- Inherits:
-
ReferenceToIdElement
- Object
- Lutaml::Model::Serializable
- EmptyElements::BasicElement
- ReferenceElement
- ReferenceToIdElement
- Metanorma::Document::Components::ReferenceElements::Callout
- Defined in:
- lib/metanorma/document/components/reference_elements/callout.rb
Overview
Inline reference to a paragraph or paragraphs, appearing as annotation of source code. The target of the callout is understood to be the location of the callout within the source code; the extent of the target is not expressed overtly.