Class: Metanorma::Document::Components::ReferenceElements::ReferenceElement
- Inherits:
-
EmptyElements::BasicElement
- Object
- Lutaml::Model::Serializable
- EmptyElements::BasicElement
- Metanorma::Document::Components::ReferenceElements::ReferenceElement
- Defined in:
- lib/metanorma/document/components/reference_elements/reference_element.rb
Overview
Inline element, which references an identifier of a document, a block in a document, or an element in a document.
Direct Known Subclasses
IndexXrefElement, ReferenceToCitationElement, ReferenceToIdElement, ReferenceToLinkElement, StandardDocument::Refs::ReferenceToTerm