Class: Metanorma::Document::Components::Sections::BasicSection
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Metanorma::Document::Components::Sections::BasicSection
- Defined in:
- lib/metanorma/document/components/sections/basic_section.rb
Overview
Group of blocks within text, which is a leaf node in the hierarchical organisation of text (does not contain any sections of its own).
Direct Known Subclasses
HierarchicalSection, ReferencesSection, StandardDocument::Sections::StandardSection