Class: Metanorma::Document::Components::TextElements::TextElement

Inherits:
EmptyElements::BasicElement show all
Defined in:
lib/metanorma/document/components/text_elements/text_element.rb

Overview

Inline element containing text and associated formatting information, but which does not contain any associated identifiers or references to identifiers.