Class: Metanorma::Document::Relaton::BibliographicDate
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Metanorma::Document::Relaton::BibliographicDate
- Defined in:
- lib/metanorma/document/relaton/bibliographic_date.rb
Overview
Significant date in the lifecycle of the bibliographic item.
Keeps its own mapping: relaton-bib 2.2.0.pre.alpha.1 Bib::Date has no
format attribute and no text content, and casts on→at as StringDate
(nil-ing non-ISO values like "–") — fixture dates such as