Class: Metanorma::Document::Relaton::DocumentIdentifier

Inherits:
Lutaml::Model::Serializable
  • Object
show all
Defined in:
lib/metanorma/document/relaton/document_identifier.rb

Overview

An identifier of a bibliographic item in an international standard scheme. Keeps its own mapping: relaton-bib 2.2.0.pre.alpha.1 Docidentifier inherits LocalizedMarkedUpString, whose Sanitizer strips span/semx/link/fmt-* from the content at assignment time, and reads the identifier string as content (ours is id).