Class: Metanorma::StandardDocument::Blocks::ElementName
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Metanorma::StandardDocument::Blocks::ElementName
- Defined in:
- lib/metanorma/standard_document/blocks/element_name.rb
Overview
The classes of block subject to autonumbering within an ‘AmendBlock` `newContent` element.
Class Method Summary collapse
Class Method Details
.values ⇒ Object
15 16 17 18 |
# File 'lib/metanorma/standard_document/blocks/element_name.rb', line 15 def self.values %w[requirement recommendation permission table figure admonition formula sourcecode example note] end |