Class: Metanorma::StandardDocument::Blocks::SvgMapBlock

Inherits:
StandardBlockNoNotes show all
Defined in:
lib/metanorma/standard_document/blocks/svg_map_block.rb

Overview

Wrapper around an SVG file, to update its hyperlinks with potentially document-specific links, so that the SVG file can hyperlink to anchors within the document.