Class: Metanorma::StandardDocument::Sections::MiscContainer
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Metanorma::StandardDocument::Sections::MiscContainer
- Defined in:
- lib/metanorma/standard_document/sections/misc_container.rb
Overview
Extension point for extraneous elements that need to be added to standards document from other schemas, e.g. UnitsML.
Content is stored as raw XML text since the children come from external vocabularies not defined in the metanorma schema.