Class: Metanorma::StandardDocument::Terms::Concept

Inherits:
Lutaml::Model::Serializable
  • Object
show all
Defined in:
lib/metanorma/standard_document/terms/concept.rb

Overview

Formally defined concept used in a StandardDocument, aligned to a definition. That concept may be defined as a term within the current document, or it may be defined externally.