Class: Metanorma::BasicDocument::EmptyElements::IndexElement
- Inherits:
-
BasicElement
- Object
- Lutaml::Model::Serializable
- BasicElement
- Metanorma::BasicDocument::EmptyElements::IndexElement
- Defined in:
- lib/metanorma/basic_document/empty_elements/index_element.rb
Overview
Index term, defined as applying to the location in the text where the index element appears, as a milestone.