Class: Metanorma::BasicDocument::MultiParagraph::AdmonitionBlock
- Inherits:
-
ParagraphsBlock
- Object
- Lutaml::Model::Serializable
- Blocks::BasicBlock
- Paragraphs::ParagraphBlock
- Paragraphs::ParagraphWithFootnote
- ParagraphsBlock
- Metanorma::BasicDocument::MultiParagraph::AdmonitionBlock
- Defined in:
- lib/metanorma/basic_document/multi_paragraph/admonition_block.rb
Overview
A sidebar block outside of the main flow of text, conveying particular warnings or supplementary text to the reader.