Class: Metanorma::BasicDocument::Paragraphs::ParagraphWithFootnote
- Inherits:
-
ParagraphBlock
- Object
- Lutaml::Model::Serializable
- Blocks::BasicBlock
- ParagraphBlock
- Metanorma::BasicDocument::Paragraphs::ParagraphWithFootnote
- Defined in:
- lib/metanorma/basic_document/paragraphs/paragraph_with_footnote.rb
Overview
A paragraph which may also contain footnotes. While most paragraphs in a document can contain footnotes, the distinction is necessary, as footnotes are not appropriate for all instances of paragraph content in a document (e.g. sourcecode annotations).