Class: Metanorma::BasicDocument::Sections::BasicSection
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Metanorma::BasicDocument::Sections::BasicSection
- Defined in:
- lib/metanorma/basic_document/sections/basic_section.rb
Overview
Group of blocks within text, which is a leaf node in the hierarchical organisation of text (does not contain any sections of its own).