Class: Metanorma::BasicDocument::TextElements::TextElement
- Inherits:
-
EmptyElements::BasicElement
- Object
- Lutaml::Model::Serializable
- EmptyElements::BasicElement
- Metanorma::BasicDocument::TextElements::TextElement
- Defined in:
- lib/metanorma/basic_document/text_elements/text_element.rb
Overview
Inline element containing text and associated formatting information, but which does not contain any associated identifiers or references to identifiers.
Direct Known Subclasses
EmphasisElement, KeywordElement, MonospaceElement, RubyElement, SmallCapsElement, StemElement, StrikeElement, StrongElement, SubscriptElement, SuperscriptElement, UnderlineElement