Class: Metanorma::Document::Components::IdElements::Bookmark
- Inherits:
-
IdElement
- Object
- Lutaml::Model::Serializable
- EmptyElements::BasicElement
- IdElement
- Metanorma::Document::Components::IdElements::Bookmark
- Defined in:
- lib/metanorma/document/components/id_elements/bookmark.rb
Overview
Anchor for cross-references which do not have scope over blocks or sections. Anchors within a block under the BasicDocument model cannot span across a number of inline elements; bookmarks are intended as point anchors. For that reason, the Review block has a starting reference and an optional ending reference, which can be bookmarks as well as block or section references.