Class: Metanorma::Document::Components::MultiParagraph::AdmonitionBlock
- Inherits:
-
ParagraphsBlock
- Object
- Lutaml::Model::Serializable
- Blocks::BasicBlock
- Paragraphs::ParagraphBlock
- Paragraphs::ParagraphWithFootnote
- ParagraphsBlock
- Metanorma::Document::Components::MultiParagraph::AdmonitionBlock
- Defined in:
- lib/metanorma/document/components/multi_paragraph/admonition_block.rb
Overview
A sidebar block outside of the main flow of text, conveying particular warnings or supplementary text to the reader.
Direct Known Subclasses
Instance Method Summary collapse
Methods inherited from Paragraphs::ParagraphBlock
Instance Method Details
#json_type ⇒ Object
37 38 39 |
# File 'lib/metanorma/document/components/multi_paragraph/admonition_block.rb', line 37 def json_type "admonition" end |