Class: Metanorma::Document::Components::Paragraphs::ParagraphWithFootnote
- Inherits:
-
ParagraphBlock
- Object
- Lutaml::Model::Serializable
- Blocks::BasicBlock
- ParagraphBlock
- Metanorma::Document::Components::Paragraphs::ParagraphWithFootnote
- Defined in:
- lib/metanorma/document/components/paragraphs/paragraph_with_footnote.rb
Overview
A paragraph which may also contain footnotes. While most paragraphs in a document can contain footnotes, the distinction is necessary, as footnotes are not appropriate for all instances of paragraph content in a document (e.g. sourcecode annotations).