Class: Metanorma::Document::Components::TextElements::TextElement
- Inherits:
-
EmptyElements::BasicElement
- Object
- Lutaml::Model::Serializable
- EmptyElements::BasicElement
- Metanorma::Document::Components::TextElements::TextElement
- Defined in:
- lib/metanorma/document/components/text_elements/text_element.rb
Overview
Inline element containing text and associated formatting information, but which does not contain any associated identifiers or references to identifiers.