Class: Metanorma::Document::Relaton::DateTime
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Metanorma::Document::Relaton::DateTime
- Defined in:
- lib/metanorma/document/relaton/date_time.rb
Overview
Type which allows date and time to be specified as either a Gregorian date and time, as specified in <<iso8601>>, as text, or as both.