Class: Metanorma::StandardDocument::Blocks::ImageMapBlock
- Inherits:
-
StandardBlockNoNotes
- Object
- Lutaml::Model::Serializable
- Document::Components::Blocks::BasicBlockNoNotes
- StandardBlockNoNotes
- Metanorma::StandardDocument::Blocks::ImageMapBlock
- Defined in:
- lib/metanorma/standard_document/blocks/image_map_block.rb
Overview
Wrapper around an image file, to specify an image map, with areas of an image being hyperlinked.