Class: Metanorma::StandardDocument::Elements::Select
- Inherits:
-
FormInput
- Object
- Lutaml::Model::Serializable
- FormInput
- Metanorma::StandardDocument::Elements::Select
- Defined in:
- lib/metanorma/standard_document/elements/select.rb
Overview
Input allowing the selection of a value from a list of values. The value attribute is used instead of a selected attribute on a component option