Class: Metanorma::StandardDocument::Refs::StandocLocalityStack
- Inherits:
-
Document::Relaton::LocalityStack
- Object
- Lutaml::Model::Serializable
- Document::Relaton::LocalityStack
- Metanorma::StandardDocument::Refs::StandocLocalityStack
- Defined in:
- lib/metanorma/standard_document/refs/standoc_locality_stack.rb
Overview
Description of location in a reference, which can be combined with other locations in a single citation.