Class: Metanorma::StandardDocument::Sections::ClauseHierarchicalSection

Inherits:
ClauseSection show all
Defined in:
lib/metanorma/standard_document/sections/clause_hierarchical_section.rb

Overview

Clauses in which all textual content belongs in a strict clause hierarchy. such that no blocks of text are siblings to subclauses.