Class: Metanorma::StandardDocument::Sections::DefinitionSection
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Metanorma::StandardDocument::Sections::DefinitionSection
- Defined in:
- lib/metanorma/standard_document/sections/definition_section.rb
Overview
Definition sections consist of one or more definition lists, used to define symbols and abbreviations used in the remainder of the document.
Corresponds to isodoc.rnc:
definitions = element definitions {
Section-Attributes,
( (BasicBlock+) | (dl+) )?,
definitions*
}