Class: Metanorma::StandardDocument::Sections::StandardReferencesSection
- Inherits:
-
StandardSection
- Object
- Lutaml::Model::Serializable
- Document::Components::Sections::BasicSection
- StandardSection
- Metanorma::StandardDocument::Sections::StandardReferencesSection
- Defined in:
- lib/metanorma/standard_document/sections/standard_references_section.rb
Overview
The StandardReferencesSection class within StandardDocument
is used to represent a bibliography section.
It is used to collate references within the document, where
there could be one or more of such sections within a document.
For example, some standardization documents differentiate normative or informative references, some split references into sections organized by concept relevance.
Similar to the ReferencesSection of the BasicDocument model,
they are leaf nodes which contain zero or more
bibliographical references (as modelled in Relaton), along with
any prefatory text.